from setuptools import setup

setup(name='simplpython',
      version='0.1',
      description='Easy Python | Python For Everybody',
      packages=['simplpython', 'gtts', 'playsound'],
      author_email='samit.mohnot@gmail.com',
      zip_safe=False)
